# bnf-parser
Parse Backus-Naur form syntaxs into parsers to generate ASTs of arbitrary syntaxs.

## TODOs
Add explicit types to transforms by creating an object that defines the transform, and how to create explicit type signatures from a generic one
